..
      Copyright 2010-2011 United States Government as represented by the
      Administrator of the National Aeronautics and Space Administration.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Developer Guide
===============

In this section you will find information on manila's lower level programming APIs.


Programming HowTos and Tutorials
--------------------------------
.. toctree::
    :maxdepth: 3

    development.environment
    development-environment-devstack
    unit_tests
    tempest_tests
    addmethod.openstackapi
    documenting_your_work
    adding_release_notes
    commit_message_tags


Background Concepts for manila
------------------------------
.. toctree::
   :maxdepth: 3

   architecture
   threading
   i18n
   rpc
   driver_requirements
   pool-aware-manila-scheduler

Other Resources
---------------
.. toctree::
   :maxdepth: 3

   launchpad
   gerrit

API Reference
-------------
.. toctree::
   :maxdepth: 3

   api
   api_microversion_dev
   api_microversion_history
   experimental_apis

Module Reference
----------------
.. toctree::
   :maxdepth: 3

   intro
   services
   database
   share
   share_hooks
   auth
   api
   scheduler
   fakes
   manila
   ganesha
   share_replication
   driver_filter_goodness_weigher

Capabilities and Extra-Specs
----------------------------
.. toctree::
   :maxdepth: 3

   capabilities_and_extra_specs
   export_location_metadata

Share backends feature support mapping
--------------------------------------
.. toctree::
   :maxdepth: 3

   share_back_ends_feature_support_mapping

Share backends
--------------
.. toctree::
   :maxdepth: 3

   container_driver
   zfs_on_linux_driver
   netapp_cluster_mode_driver
   emc_isilon_driver
   emc_vnx_driver
   emc_unity_driver
   generic_driver
   glusterfs_driver
   glusterfs_native_driver
   cephfs_native_driver
   gpfs_driver
   huawei_nas_driver
   hdfs_native_driver
   hitachi_hnas_driver
   hpe_3par_driver
   tegile_driver
   maprfs_native_driver

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

